/* Copyright (C) 2005 Emmanuele Bassi <ebassi@gmail.com>
 * Copyright (C) 2012-2021 MATE Developers
 *
 * This file is part of MATE Utils.
 *
 * MATE Utils is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * MATE Utils is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MATE Utils.  If not, see <https://www.gnu.org/licenses/>.
 */

#ifndef __GDICT_H__
#define __GDICT_H__

#include "gdict-context.h"
#include "gdict-client-context.h"
#include "gdict-source.h"
#include "gdict-source-loader.h"
#include "gdict-source-chooser.h"
#include "gdict-database-chooser.h"
#include "gdict-defbox.h"
#include "gdict-speller.h"
#include "gdict-strategy-chooser.h"
#include "gdict-utils.h"
#include "gdict-enum-types.h"
#include "gdict-version.h"

#endif /* __GDICT_H__ */
